===============================
Yo Payments
===============================

.. image:: https://badge.fury.io/py/yo_payments.png
    :target: http://badge.fury.io/py/yo_payments

.. image:: https://pypip.in/d/yo_payments/badge.png
	:target: https://crate.io/packages/yo_payments?version=latest

.. image:: https://travis-ci.org/JamesMura/yo_payments.svg?branch=master
    :target: https://travis-ci.org/JamesMura/yo_payments


.. image:: https://coveralls.io/repos/JamesMura/yo_payments/badge.png
    :target: https://coveralls.io/r/JamesMura/yo_payments

.. image:: https://badges.gitter.im/Join Chat.svg
    :target: https://gitter.im/JamesMura/yo_payments?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
Api Wrapper for the Yo Payments service

* Free software: MIT license
* Documentation: http://yo_payments.rtfd.org.


